Class: Sendmux::Mailbox::Generated::BatchUpdateMailboxMessagesBody

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BatchUpdateMailboxMessagesBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::BatchUpdateMailboxMessagesBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::BatchUpdateMailboxMessagesBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flagged')
    self.flagged = attributes[:'flagged']
  end

  if attributes.key?(:'ids')
    if (value = attributes[:'ids']).is_a?(Array)
      self.ids = value
    end
  else
    self.ids = nil
  end

  if attributes.key?(:'if_in_state')
    self.if_in_state = attributes[:'if_in_state']
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Hash)
      self.keywords = value
    end
  end

  if attributes.key?(:'seen')
    self.seen = attributes[:'seen']
  end
end

Instance Attribute Details

#flaggedObject

Returns the value of attribute flagged.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 18

def flagged
  @flagged
end

#idsObject

Returns the value of attribute ids.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 20

def ids
  @ids
end

#if_in_stateObject

Optional message state token for stale-write protection.



23
24
25
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 23

def if_in_state
  @if_in_state
end

#keywordsObject

Map of message keyword names to booleans. ‘true` sets the keyword; `false` clears it. Keyword names are normalised to lowercase. Lifecycle keywords such as `$draft` are read-only.



26
27
28
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 26

def keywords
  @keywords
end

#seenObject

Returns the value of attribute seen.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 28

def seen
  @seen
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 31

def self.attribute_map
  {
    :'flagged' => :'flagged',
    :'ids' => :'ids',
    :'if_in_state' => :'if_in_state',
    :'keywords' => :'keywords',
    :'seen' => :'seen'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 52

def self.openapi_types
  {
    :'flagged' => :'Boolean',
    :'ids' => :'Array<String>',
    :'if_in_state' => :'String',
    :'keywords' => :'Hash<String, Boolean>',
    :'seen' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



161
162
163
164
165
166
167
168
169
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flagged == o.flagged &&
      ids == o.ids &&
      if_in_state == o.if_in_state &&
      keywords == o.keywords &&
      seen == o.seen
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 179

def hash
  [flagged, ids, if_in_state, keywords, seen].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ids.nil?
    invalid_properties.push('invalid value for "ids", ids cannot be nil.')
  end

  if @ids.length > 100
    invalid_properties.push('invalid value for "ids", number of items must be less than or equal to 100.')
  end

  if @ids.length < 1
    invalid_properties.push('invalid value for "ids", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
139
# File 'lib/sendmux_mailbox_generated/models/batch_update_mailbox_messages_body.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ids.nil?
  return false if @ids.length > 100
  return false if @ids.length < 1
  true
end