Class: Sendmux::Mailbox::Generated::MailboxAttachment

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_attachment.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxAttachment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxAttachment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxAttachment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'content_id')
    self.content_id = attributes[:'content_id']
  else
    self.content_id = nil
  end

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  else
    self.content_type = nil
  end

  if attributes.key?(:'disposition')
    self.disposition = attributes[:'disposition']
  else
    self.disposition = nil
  end

  if attributes.key?(:'download_url')
    self.download_url = attributes[:'download_url']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  else
    self.filename = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  else
    self.size_bytes = nil
  end
end

Instance Attribute Details

#content_idObject

Content ID for inline attachments, when present.



19
20
21
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 19

def content_id
  @content_id
end

#content_typeObject

Returns the value of attribute content_type.



21
22
23
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 21

def content_type
  @content_type
end

#dispositionObject

Returns the value of attribute disposition.



23
24
25
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 23

def disposition
  @disposition
end

#download_urlObject

Short-lived URL for this exact attachment. Fetch it promptly; if it expires, call the message or attachment metadata endpoint again to receive a fresh URL.



26
27
28
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 26

def download_url
  @download_url
end

#filenameObject

Returns the value of attribute filename.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 28

def filename
  @filename
end

#idObject

Attachment blob ID.



31
32
33
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 31

def id
  @id
end

#size_bytesObject

Returns the value of attribute size_bytes.



33
34
35
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 33

def size_bytes
  @size_bytes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 36

def self.attribute_map
  {
    :'content_id' => :'content_id',
    :'content_type' => :'content_type',
    :'disposition' => :'disposition',
    :'download_url' => :'download_url',
    :'filename' => :'filename',
    :'id' => :'id',
    :'size_bytes' => :'size_bytes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
77
78
79
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 72

def self.openapi_nullable
  Set.new([
    :'content_id',
    :'disposition',
    :'filename',
    :'size_bytes'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 59

def self.openapi_types
  {
    :'content_id' => :'String',
    :'content_type' => :'String',
    :'disposition' => :'String',
    :'download_url' => :'String',
    :'filename' => :'String',
    :'id' => :'String',
    :'size_bytes' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
192
193
194
195
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      content_id == o.content_id &&
      content_type == o.content_type &&
      disposition == o.disposition &&
      download_url == o.download_url &&
      filename == o.filename &&
      id == o.id &&
      size_bytes == o.size_bytes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 205

def hash
  [content_id, content_type, disposition, download_url, filename, id, size_bytes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @content_type.nil?
    invalid_properties.push('invalid value for "content_type", content_type cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @content_type.nil?
  return false if @id.nil?
  true
end