Class: Sendmux::Mailbox::Generated::MailboxAttachmentUploadIntentResult

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxAttachmentUploadIntentResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxAttachmentUploadIntentResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxAttachmentUploadIntentResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'headers')
    self.headers = attributes[:'headers']
  else
    self.headers = nil
  end

  if attributes.key?(:'max_size_bytes')
    self.max_size_bytes = attributes[:'max_size_bytes']
  else
    self.max_size_bytes = nil
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'upload_id')
    self.upload_id = attributes[:'upload_id']
  else
    self.upload_id = nil
  end

  if attributes.key?(:'upload_url')
    self.upload_url = attributes[:'upload_url']
  else
    self.upload_url = nil
  end
end

Instance Attribute Details

#expires_atObject

Upload URL expiry time.



19
20
21
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 19

def expires_at
  @expires_at
end

#headersObject

Returns the value of attribute headers.



21
22
23
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 21

def headers
  @headers
end

#max_size_bytesObject

Maximum accepted attachment size in bytes.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 24

def max_size_bytes
  @max_size_bytes
end

#methodObject

HTTP method to use with upload_url.



27
28
29
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 27

def method
  @method
end

#upload_idObject

Short-lived upload intent ID.



30
31
32
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 30

def upload_id
  @upload_id
end

#upload_urlObject

Short-lived signed PUT URL for this exact attachment. Upload promptly; if it expires, create a new upload URL.



33
34
35
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 33

def upload_url
  @upload_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 58

def self.attribute_map
  {
    :'expires_at' => :'expires_at',
    :'headers' => :'headers',
    :'max_size_bytes' => :'max_size_bytes',
    :'method' => :'method',
    :'upload_id' => :'upload_id',
    :'upload_url' => :'upload_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 285

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 80

def self.openapi_types
  {
    :'expires_at' => :'Time',
    :'headers' => :'MailboxAttachmentUploadIntentResultHeaders',
    :'max_size_bytes' => :'Integer',
    :'method' => :'String',
    :'upload_id' => :'String',
    :'upload_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



259
260
261
262
263
264
265
266
267
268
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 259

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      expires_at == o.expires_at &&
      headers == o.headers &&
      max_size_bytes == o.max_size_bytes &&
      method == o.method &&
      upload_id == o.upload_id &&
      upload_url == o.upload_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 278

def hash
  [expires_at, headers, max_size_bytes, method, upload_id, upload_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @headers.nil?
    invalid_properties.push('invalid value for "headers", headers cannot be nil.')
  end

  if @max_size_bytes.nil?
    invalid_properties.push('invalid value for "max_size_bytes", max_size_bytes cannot be nil.')
  end

  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  if @upload_id.nil?
    invalid_properties.push('invalid value for "upload_id", upload_id cannot be nil.')
  end

  if @upload_url.nil?
    invalid_properties.push('invalid value for "upload_url", upload_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/sendmux_mailbox_generated/models/mailbox_attachment_upload_intent_result.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @expires_at.nil?
  return false if @headers.nil?
  return false if @max_size_bytes.nil?
  return false if @method.nil?
  method_validator = EnumAttributeValidator.new('String', ["PUT", "unknown_default_open_api"])
  return false unless method_validator.valid?(@method)
  return false if @upload_id.nil?
  return false if @upload_url.nil?
  true
end