Class: Sendmux::Mailbox::Generated::MailboxBatchUpdateMessagesResult

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxBatchUpdateMessagesResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxBatchUpdateMessagesResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxBatchUpdateMessagesResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'failed')
    if (value = attributes[:'failed']).is_a?(Array)
      self.failed = value
    end
  else
    self.failed = nil
  end

  if attributes.key?(:'not_found')
    if (value = attributes[:'not_found']).is_a?(Array)
      self.not_found = value
    end
  else
    self.not_found = nil
  end

  if attributes.key?(:'states')
    self.states = attributes[:'states']
  else
    self.states = nil
  end

  if attributes.key?(:'updated')
    if (value = attributes[:'updated']).is_a?(Array)
      self.updated = value
    end
  else
    self.updated = nil
  end
end

Instance Attribute Details

#failedObject

Returns the value of attribute failed.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 18

def failed
  @failed
end

#not_foundObject

Returns the value of attribute not_found.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 20

def not_found
  @not_found
end

#statesObject

Returns the value of attribute states.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 22

def states
  @states
end

#updatedObject

Returns the value of attribute updated.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 24

def updated
  @updated
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 27

def self.attribute_map
  {
    :'failed' => :'failed',
    :'not_found' => :'not_found',
    :'states' => :'states',
    :'updated' => :'updated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 47

def self.openapi_types
  {
    :'failed' => :'Array<MailboxBatchMessageFailure>',
    :'not_found' => :'Array<String>',
    :'states' => :'MailboxBatchMessageStates',
    :'updated' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      failed == o.failed &&
      not_found == o.not_found &&
      states == o.states &&
      updated == o.updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 203

def hash
  [failed, not_found, states, updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @failed.nil?
    invalid_properties.push('invalid value for "failed", failed cannot be nil.')
  end

  if @not_found.nil?
    invalid_properties.push('invalid value for "not_found", not_found cannot be nil.')
  end

  if @states.nil?
    invalid_properties.push('invalid value for "states", states cannot be nil.')
  end

  if @updated.nil?
    invalid_properties.push('invalid value for "updated", updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
141
142
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_update_messages_result.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @failed.nil?
  return false if @not_found.nil?
  return false if @states.nil?
  return false if @updated.nil?
  true
end