Class: Sendmux::Mailbox::Generated::MailboxChanges
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxChanges
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_changes.rb
Instance Attribute Summary collapse
-
#created ⇒ Object
Returns the value of attribute created.
-
#destroyed ⇒ Object
Returns the value of attribute destroyed.
-
#has_more ⇒ Object
Returns the value of attribute has_more.
-
#new_state ⇒ Object
Returns the value of attribute new_state.
-
#old_state ⇒ Object
Returns the value of attribute old_state.
-
#sync_required ⇒ Object
When true, refetch this resource list instead of applying the incremental arrays.
-
#updated ⇒ Object
Returns the value of attribute updated.
-
#updated_properties ⇒ Object
Returns the value of attribute updated_properties.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxChanges
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxChanges
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxChanges` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxChanges`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created') if (value = attributes[:'created']).is_a?(Array) self.created = value end else self.created = nil end if attributes.key?(:'destroyed') if (value = attributes[:'destroyed']).is_a?(Array) self.destroyed = value end else self.destroyed = nil end if attributes.key?(:'has_more') self.has_more = attributes[:'has_more'] else self.has_more = nil end if attributes.key?(:'new_state') self.new_state = attributes[:'new_state'] else self.new_state = nil end if attributes.key?(:'old_state') self.old_state = attributes[:'old_state'] else self.old_state = nil end if attributes.key?(:'sync_required') self.sync_required = attributes[:'sync_required'] end if attributes.key?(:'updated') if (value = attributes[:'updated']).is_a?(Array) self.updated = value end else self.updated = nil end if attributes.key?(:'updated_properties') if (value = attributes[:'updated_properties']).is_a?(Array) self.updated_properties = value end end end |
Instance Attribute Details
#created ⇒ Object
Returns the value of attribute created.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 18 def created @created end |
#destroyed ⇒ Object
Returns the value of attribute destroyed.
20 21 22 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 20 def destroyed @destroyed end |
#has_more ⇒ Object
Returns the value of attribute has_more.
22 23 24 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 22 def has_more @has_more end |
#new_state ⇒ Object
Returns the value of attribute new_state.
24 25 26 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 24 def new_state @new_state end |
#old_state ⇒ Object
Returns the value of attribute old_state.
26 27 28 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 26 def old_state @old_state end |
#sync_required ⇒ Object
When true, refetch this resource list instead of applying the incremental arrays.
29 30 31 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 29 def sync_required @sync_required end |
#updated ⇒ Object
Returns the value of attribute updated.
31 32 33 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 31 def updated @updated end |
#updated_properties ⇒ Object
Returns the value of attribute updated_properties.
33 34 35 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 33 def updated_properties @updated_properties end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 36 def self.attribute_map { :'created' => :'created', :'destroyed' => :'destroyed', :'has_more' => :'has_more', :'new_state' => :'new_state', :'old_state' => :'old_state', :'sync_required' => :'sync_required', :'updated' => :'updated', :'updated_properties' => :'updated_properties' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 269 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 78 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 74 def self.openapi_nullable Set.new([ :'old_state', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 60 def self.openapi_types { :'created' => :'Array<String>', :'destroyed' => :'Array<String>', :'has_more' => :'Boolean', :'new_state' => :'String', :'old_state' => :'String', :'sync_required' => :'Boolean', :'updated' => :'Array<String>', :'updated_properties' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && destroyed == o.destroyed && has_more == o.has_more && new_state == o.new_state && old_state == o.old_state && sync_required == o.sync_required && updated == o.updated && updated_properties == o.updated_properties end |
#eql?(o) ⇒ Boolean
256 257 258 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 256 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 262 def hash [created, destroyed, has_more, new_state, old_state, sync_required, updated, updated_properties].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @destroyed.nil? invalid_properties.push('invalid value for "destroyed", destroyed cannot be nil.') end if @has_more.nil? invalid_properties.push('invalid value for "has_more", has_more cannot be nil.') end if @new_state.nil? invalid_properties.push('invalid value for "new_state", new_state cannot be nil.') end if @updated.nil? invalid_properties.push('invalid value for "updated", updated cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 291 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created.nil? return false if @destroyed.nil? return false if @has_more.nil? return false if @new_state.nil? return false if @updated.nil? true end |