Class: Sendmux::Mailbox::Generated::MailboxContentHeadersSelected

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxContentHeadersSelected

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxContentHeadersSelected` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxContentHeadersSelected`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'in_reply_to')
    self.in_reply_to = attributes[:'in_reply_to']
  else
    self.in_reply_to = nil
  end

  if attributes.key?(:'message_id')
    if (value = attributes[:'message_id']).is_a?(Array)
      self.message_id = value
    end
  else
    self.message_id = nil
  end

  if attributes.key?(:'references')
    if (value = attributes[:'references']).is_a?(Array)
      self.references = value
    end
  else
    self.references = nil
  end

  if attributes.key?(:'reply_to')
    if (value = attributes[:'reply_to']).is_a?(Array)
      self.reply_to = value
    end
  else
    self.reply_to = nil
  end
end

Instance Attribute Details

#in_reply_toObject

Returns the value of attribute in_reply_to.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 18

def in_reply_to
  @in_reply_to
end

#message_idObject

Returns the value of attribute message_id.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 20

def message_id
  @message_id
end

#referencesObject

Returns the value of attribute references.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 22

def references
  @references
end

#reply_toObject

Returns the value of attribute reply_to.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 24

def reply_to
  @reply_to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 27

def self.attribute_map
  {
    :'in_reply_to' => :'in_reply_to',
    :'message_id' => :'message_id',
    :'references' => :'references',
    :'reply_to' => :'reply_to'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 57

def self.openapi_nullable
  Set.new([
    :'in_reply_to',
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 47

def self.openapi_types
  {
    :'in_reply_to' => :'String',
    :'message_id' => :'Array<String>',
    :'references' => :'Array<String>',
    :'reply_to' => :'Array<MailboxAddress>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      in_reply_to == o.in_reply_to &&
      message_id == o.message_id &&
      references == o.references &&
      reply_to == o.reply_to
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 189

def hash
  [in_reply_to, message_id, references, reply_to].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 112

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @message_id.nil?
    invalid_properties.push('invalid value for "message_id", message_id cannot be nil.')
  end

  if @references.nil?
    invalid_properties.push('invalid value for "references", references cannot be nil.')
  end

  if @reply_to.nil?
    invalid_properties.push('invalid value for "reply_to", reply_to cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
137
138
# File 'lib/sendmux_mailbox_generated/models/mailbox_content_headers_selected.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @message_id.nil?
  return false if @references.nil?
  return false if @reply_to.nil?
  true
end