Class: Sendmux::Mailbox::Generated::MailboxMe

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_me.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxMe

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxMe` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxMe`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  else
    self.display_name = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'quota_bytes')
    self.quota_bytes = attributes[:'quota_bytes']
  else
    self.quota_bytes = nil
  end

  if attributes.key?(:'send_scope')
    self.send_scope = attributes[:'send_scope']
  else
    self.send_scope = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'quota_used_bytes')
    self.quota_used_bytes = attributes[:'quota_used_bytes']
  end
end

Instance Attribute Details

#created_atObject

ISO 8601 creation timestamp



19
20
21
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 19

def created_at
  @created_at
end

#display_nameObject

Optional display name shown in outbound From headers



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 22

def display_name
  @display_name
end

#emailObject

Mailbox email address (lowercase)



25
26
27
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 25

def email
  @email
end

#idObject

Public ID



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 28

def id
  @id
end

#quota_bytesObject

Storage quota in bytes. Current writable tiers are 1 GB, 5 GB, and 50 GB.



31
32
33
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 31

def quota_bytes
  @quota_bytes
end

#quota_used_bytesObject

Live storage usage in bytes. Omitted when usage is temporarily unavailable.



39
40
41
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 39

def quota_used_bytes
  @quota_used_bytes
end

#send_scopeObject

Returns the value of attribute send_scope.



33
34
35
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 33

def send_scope
  @send_scope
end

#statusObject

active | suspended | deleted



36
37
38
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 36

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 42

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'display_name' => :'display_name',
    :'email' => :'email',
    :'id' => :'id',
    :'quota_bytes' => :'quota_bytes',
    :'send_scope' => :'send_scope',
    :'status' => :'status',
    :'quota_used_bytes' => :'quota_used_bytes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 263

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



89
90
91
92
93
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 89

def self.openapi_all_of
  [
  :'Mailbox'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
84
85
86
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 80

def self.openapi_nullable
  Set.new([
    :'display_name',
    :'quota_bytes',
    :'send_scope',
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 66

def self.openapi_types
  {
    :'created_at' => :'String',
    :'display_name' => :'String',
    :'email' => :'String',
    :'id' => :'String',
    :'quota_bytes' => :'Integer',
    :'send_scope' => :'MailboxSendScope',
    :'status' => :'String',
    :'quota_used_bytes' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      display_name == o.display_name &&
      email == o.email &&
      id == o.id &&
      quota_bytes == o.quota_bytes &&
      send_scope == o.send_scope &&
      status == o.status &&
      quota_used_bytes == o.quota_used_bytes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


250
251
252
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 250

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



256
257
258
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 256

def hash
  [created_at, display_name, email, id, quota_bytes, send_scope, status, quota_used_bytes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 160

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 285

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
# File 'lib/sendmux_mailbox_generated/models/mailbox_me.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @email.nil?
  return false if @id.nil?
  return false if @status.nil?
  true
end