Class: Sendmux::Mailbox::Generated::MailboxMessage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxMessage
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_message.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#bcc ⇒ Object
Returns the value of attribute bcc.
-
#cc ⇒ Object
Returns the value of attribute cc.
-
#flags ⇒ Object
Returns the value of attribute flags.
-
#folder_ids ⇒ Object
Returns the value of attribute folder_ids.
-
#from ⇒ Object
Returns the value of attribute from.
-
#has_attachments ⇒ Object
Returns the value of attribute has_attachments.
-
#html_body ⇒ Object
Returns the value of attribute html_body.
-
#id ⇒ Object
Message ID.
-
#keywords ⇒ Object
Active message keywords, including system flags and custom labels.
-
#preview ⇒ Object
Returns the value of attribute preview.
-
#received_at ⇒ Object
Returns the value of attribute received_at.
-
#sent_at ⇒ Object
Returns the value of attribute sent_at.
-
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#text_body ⇒ Object
Returns the value of attribute text_body.
-
#thread_id ⇒ Object
Returns the value of attribute thread_id.
-
#to ⇒ Object
Returns the value of attribute to.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxMessage
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 137 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'bcc') if (value = attributes[:'bcc']).is_a?(Array) self.bcc = value end else self.bcc = nil end if attributes.key?(:'cc') if (value = attributes[:'cc']).is_a?(Array) self.cc = value end else self.cc = nil end if attributes.key?(:'flags') self.flags = attributes[:'flags'] else self.flags = nil end if attributes.key?(:'folder_ids') if (value = attributes[:'folder_ids']).is_a?(Array) self.folder_ids = value end else self.folder_ids = nil end if attributes.key?(:'from') self.from = attributes[:'from'] else self.from = nil end if attributes.key?(:'has_attachments') self. = attributes[:'has_attachments'] else self. = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end else self.keywords = nil end if attributes.key?(:'preview') self.preview = attributes[:'preview'] else self.preview = nil end if attributes.key?(:'received_at') self.received_at = attributes[:'received_at'] else self.received_at = nil end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] else self.sent_at = nil end if attributes.key?(:'size_bytes') self.size_bytes = attributes[:'size_bytes'] else self.size_bytes = nil end if attributes.key?(:'subject') self.subject = attributes[:'subject'] else self.subject = nil end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] else self.thread_id = nil end if attributes.key?(:'to') if (value = attributes[:'to']).is_a?(Array) self.to = value end else self.to = nil end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'html_body') self.html_body = attributes[:'html_body'] else self.html_body = nil end if attributes.key?(:'text_body') self.text_body = attributes[:'text_body'] else self.text_body = nil end end |
Instance Attribute Details
#attachments ⇒ Object
Returns the value of attribute attachments.
50 51 52 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 50 def @attachments end |
#bcc ⇒ Object
Returns the value of attribute bcc.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 18 def bcc @bcc end |
#cc ⇒ Object
Returns the value of attribute cc.
20 21 22 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 20 def cc @cc end |
#flags ⇒ Object
Returns the value of attribute flags.
22 23 24 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 22 def flags @flags end |
#folder_ids ⇒ Object
Returns the value of attribute folder_ids.
24 25 26 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 24 def folder_ids @folder_ids end |
#from ⇒ Object
Returns the value of attribute from.
26 27 28 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 26 def from @from end |
#has_attachments ⇒ Object
Returns the value of attribute has_attachments.
28 29 30 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 28 def @has_attachments end |
#html_body ⇒ Object
Returns the value of attribute html_body.
52 53 54 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 52 def html_body @html_body end |
#id ⇒ Object
Message ID
31 32 33 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 31 def id @id end |
#keywords ⇒ Object
Active message keywords, including system flags and custom labels.
34 35 36 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 34 def keywords @keywords end |
#preview ⇒ Object
Returns the value of attribute preview.
36 37 38 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 36 def preview @preview end |
#received_at ⇒ Object
Returns the value of attribute received_at.
38 39 40 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 38 def received_at @received_at end |
#sent_at ⇒ Object
Returns the value of attribute sent_at.
40 41 42 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 40 def sent_at @sent_at end |
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
42 43 44 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 42 def size_bytes @size_bytes end |
#subject ⇒ Object
Returns the value of attribute subject.
44 45 46 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 44 def subject @subject end |
#text_body ⇒ Object
Returns the value of attribute text_body.
54 55 56 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 54 def text_body @text_body end |
#thread_id ⇒ Object
Returns the value of attribute thread_id.
46 47 48 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 46 def thread_id @thread_id end |
#to ⇒ Object
Returns the value of attribute to.
48 49 50 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 48 def to @to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 57 def self.attribute_map { :'bcc' => :'bcc', :'cc' => :'cc', :'flags' => :'flags', :'folder_ids' => :'folder_ids', :'from' => :'from', :'has_attachments' => :'has_attachments', :'id' => :'id', :'keywords' => :'keywords', :'preview' => :'preview', :'received_at' => :'received_at', :'sent_at' => :'sent_at', :'size_bytes' => :'size_bytes', :'subject' => :'subject', :'thread_id' => :'thread_id', :'to' => :'to', :'attachments' => :'attachments', :'html_body' => :'html_body', :'text_body' => :'text_body' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 477 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
129 130 131 132 133 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 129 def self.openapi_all_of [ :'MailboxMessageSummary' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 115 def self.openapi_nullable Set.new([ :'preview', :'received_at', :'sent_at', :'size_bytes', :'subject', :'thread_id', :'html_body', :'text_body' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 91 def self.openapi_types { :'bcc' => :'Array<MailboxAddress>', :'cc' => :'Array<MailboxAddress>', :'flags' => :'MailboxMessageFlags', :'folder_ids' => :'Array<String>', :'from' => :'MailboxMessageSummaryFrom', :'has_attachments' => :'Boolean', :'id' => :'String', :'keywords' => :'Array<String>', :'preview' => :'String', :'received_at' => :'String', :'sent_at' => :'String', :'size_bytes' => :'Integer', :'subject' => :'String', :'thread_id' => :'String', :'to' => :'Array<MailboxAddress>', :'attachments' => :'Array<MailboxAttachment>', :'html_body' => :'String', :'text_body' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 439 def ==(o) return true if self.equal?(o) self.class == o.class && bcc == o.bcc && cc == o.cc && flags == o.flags && folder_ids == o.folder_ids && from == o.from && == o. && id == o.id && keywords == o.keywords && preview == o.preview && received_at == o.received_at && sent_at == o.sent_at && size_bytes == o.size_bytes && subject == o.subject && thread_id == o.thread_id && to == o.to && == o. && html_body == o.html_body && text_body == o.text_body end |
#eql?(o) ⇒ Boolean
464 465 466 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 464 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
470 471 472 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 470 def hash [bcc, cc, flags, folder_ids, from, , id, keywords, preview, received_at, sent_at, size_bytes, subject, thread_id, to, , html_body, text_body].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 274 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @bcc.nil? invalid_properties.push('invalid value for "bcc", bcc cannot be nil.') end if @cc.nil? invalid_properties.push('invalid value for "cc", cc cannot be nil.') end if @flags.nil? invalid_properties.push('invalid value for "flags", flags cannot be nil.') end if @folder_ids.nil? invalid_properties.push('invalid value for "folder_ids", folder_ids cannot be nil.') end if @from.nil? invalid_properties.push('invalid value for "from", from cannot be nil.') end if @has_attachments.nil? invalid_properties.push('invalid value for "has_attachments", has_attachments cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @keywords.nil? invalid_properties.push('invalid value for "keywords", keywords cannot be nil.') end if @to.nil? invalid_properties.push('invalid value for "to", to cannot be nil.') end if @attachments.nil? invalid_properties.push('invalid value for "attachments", attachments cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
499 500 501 502 503 504 505 506 507 508 509 510 511 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 499 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_message.rb', line 322 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @bcc.nil? return false if @cc.nil? return false if @flags.nil? return false if @folder_ids.nil? return false if @from.nil? return false if @has_attachments.nil? return false if @id.nil? return false if @keywords.nil? return false if @to.nil? return false if @attachments.nil? true end |