Class: Sendmux::Mailbox::Generated::MailboxMessageContent

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_message_content.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxMessageContent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxMessageContent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxMessageContent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  else
    self.attachments = nil
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'dates')
    self.dates = attributes[:'dates']
  else
    self.dates = nil
  end

  if attributes.key?(:'headers')
    self.headers = attributes[:'headers']
  else
    self.headers = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'participants')
    self.participants = attributes[:'participants']
  else
    self.participants = nil
  end

  if attributes.key?(:'states')
    self.states = attributes[:'states']
  else
    self.states = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'thread_id')
    self.thread_id = attributes[:'thread_id']
  else
    self.thread_id = nil
  end
end

Instance Attribute Details

#attachmentsObject

Attachment metadata only. Attachment contents are not parsed by this endpoint.



19
20
21
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 19

def attachments
  @attachments
end

#bodyObject

Returns the value of attribute body.



21
22
23
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 21

def body
  @body
end

#datesObject

Returns the value of attribute dates.



23
24
25
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 23

def dates
  @dates
end

#headersObject

Returns the value of attribute headers.



25
26
27
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 25

def headers
  @headers
end

#idObject

Message ID



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 28

def id
  @id
end

#participantsObject

Returns the value of attribute participants.



30
31
32
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 30

def participants
  @participants
end

#statesObject

Returns the value of attribute states.



32
33
34
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 32

def states
  @states
end

#subjectObject

Returns the value of attribute subject.



34
35
36
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 34

def subject
  @subject
end

#thread_idObject

Returns the value of attribute thread_id.



36
37
38
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 36

def thread_id
  @thread_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 39

def self.attribute_map
  {
    :'attachments' => :'attachments',
    :'body' => :'body',
    :'dates' => :'dates',
    :'headers' => :'headers',
    :'id' => :'id',
    :'participants' => :'participants',
    :'states' => :'states',
    :'subject' => :'subject',
    :'thread_id' => :'thread_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 310

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
83
84
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 79

def self.openapi_nullable
  Set.new([
    :'subject',
    :'thread_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 64

def self.openapi_types
  {
    :'attachments' => :'Array<MailboxAttachment>',
    :'body' => :'MailboxMessageContentBody',
    :'dates' => :'MailboxMessageContentDates',
    :'headers' => :'MailboxContentHeaders',
    :'id' => :'String',
    :'participants' => :'MailboxMessageContentParticipants',
    :'states' => :'MailboxMessageContentStates',
    :'subject' => :'String',
    :'thread_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 281

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attachments == o.attachments &&
      body == o.body &&
      dates == o.dates &&
      headers == o.headers &&
      id == o.id &&
      participants == o.participants &&
      states == o.states &&
      subject == o.subject &&
      thread_id == o.thread_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


297
298
299
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 297

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



303
304
305
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 303

def hash
  [attachments, body, dates, headers, id, participants, states, subject, thread_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @attachments.nil?
    invalid_properties.push('invalid value for "attachments", attachments cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @dates.nil?
    invalid_properties.push('invalid value for "dates", dates cannot be nil.')
  end

  if @headers.nil?
    invalid_properties.push('invalid value for "headers", headers cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @participants.nil?
    invalid_properties.push('invalid value for "participants", participants cannot be nil.')
  end

  if @states.nil?
    invalid_properties.push('invalid value for "states", states cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 332

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
203
204
205
206
207
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_content.rb', line 197

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @attachments.nil?
  return false if @body.nil?
  return false if @dates.nil?
  return false if @headers.nil?
  return false if @id.nil?
  return false if @participants.nil?
  return false if @states.nil?
  true
end