Class: Sendmux::Mailbox::Generated::MailboxMessageQueryChanges

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxMessageQueryChanges

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxMessageQueryChanges` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxMessageQueryChanges`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'added')
    if (value = attributes[:'added']).is_a?(Array)
      self.added = value
    end
  else
    self.added = nil
  end

  if attributes.key?(:'has_more')
    self.has_more = attributes[:'has_more']
  else
    self.has_more = nil
  end

  if attributes.key?(:'new_query_state')
    self.new_query_state = attributes[:'new_query_state']
  else
    self.new_query_state = nil
  end

  if attributes.key?(:'old_query_state')
    self.old_query_state = attributes[:'old_query_state']
  else
    self.old_query_state = nil
  end

  if attributes.key?(:'removed')
    if (value = attributes[:'removed']).is_a?(Array)
      self.removed = value
    end
  else
    self.removed = nil
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end
end

Instance Attribute Details

#addedObject

Returns the value of attribute added.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 18

def added
  @added
end

#has_moreObject

Returns the value of attribute has_more.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 20

def has_more
  @has_more
end

#new_query_stateObject

Returns the value of attribute new_query_state.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 22

def new_query_state
  @new_query_state
end

#old_query_stateObject

Returns the value of attribute old_query_state.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 24

def old_query_state
  @old_query_state
end

#removedObject

Returns the value of attribute removed.



26
27
28
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 26

def removed
  @removed
end

#totalObject

Returns the value of attribute total.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 28

def total
  @total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 31

def self.attribute_map
  {
    :'added' => :'added',
    :'has_more' => :'has_more',
    :'new_query_state' => :'new_query_state',
    :'old_query_state' => :'old_query_state',
    :'removed' => :'removed',
    :'total' => :'total'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 232

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 65

def self.openapi_nullable
  Set.new([
    :'old_query_state',
    :'total'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 53

def self.openapi_types
  {
    :'added' => :'Array<MailboxFolderQueryChangesAddedInner>',
    :'has_more' => :'Boolean',
    :'new_query_state' => :'String',
    :'old_query_state' => :'String',
    :'removed' => :'Array<String>',
    :'total' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
214
215
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      added == o.added &&
      has_more == o.has_more &&
      new_query_state == o.new_query_state &&
      old_query_state == o.old_query_state &&
      removed == o.removed &&
      total == o.total
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 225

def hash
  [added, has_more, new_query_state, old_query_state, removed, total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @added.nil?
    invalid_properties.push('invalid value for "added", added cannot be nil.')
  end

  if @has_more.nil?
    invalid_properties.push('invalid value for "has_more", has_more cannot be nil.')
  end

  if @new_query_state.nil?
    invalid_properties.push('invalid value for "new_query_state", new_query_state cannot be nil.')
  end

  if @removed.nil?
    invalid_properties.push('invalid value for "removed", removed cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
162
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_query_changes.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @added.nil?
  return false if @has_more.nil?
  return false if @new_query_state.nil?
  return false if @removed.nil?
  true
end