Class: Sendmux::Mailbox::Generated::MailboxMessageSummary

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxMessageSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxMessageSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxMessageSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'bcc')
    if (value = attributes[:'bcc']).is_a?(Array)
      self.bcc = value
    end
  else
    self.bcc = nil
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  else
    self.cc = nil
  end

  if attributes.key?(:'flags')
    self.flags = attributes[:'flags']
  else
    self.flags = nil
  end

  if attributes.key?(:'folder_ids')
    if (value = attributes[:'folder_ids']).is_a?(Array)
      self.folder_ids = value
    end
  else
    self.folder_ids = nil
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  else
    self.from = nil
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Array)
      self.keywords = value
    end
  else
    self.keywords = nil
  end

  if attributes.key?(:'preview')
    self.preview = attributes[:'preview']
  else
    self.preview = nil
  end

  if attributes.key?(:'received_at')
    self.received_at = attributes[:'received_at']
  else
    self.received_at = nil
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  else
    self.sent_at = nil
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  else
    self.size_bytes = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'thread_id')
    self.thread_id = attributes[:'thread_id']
  else
    self.thread_id = nil
  end

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  else
    self.to = nil
  end
end

Instance Attribute Details

#attachmentsObject

Attachment metadata for this message. Each item includes a short-lived download_url; if it expires, fetch message metadata again.



19
20
21
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 19

def attachments
  @attachments
end

#bccObject

Returns the value of attribute bcc.



21
22
23
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 21

def bcc
  @bcc
end

#ccObject

Returns the value of attribute cc.



23
24
25
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 23

def cc
  @cc
end

#flagsObject

Returns the value of attribute flags.



25
26
27
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 25

def flags
  @flags
end

#folder_idsObject

Returns the value of attribute folder_ids.



27
28
29
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 27

def folder_ids
  @folder_ids
end

#fromObject

Returns the value of attribute from.



29
30
31
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 29

def from
  @from
end

#has_attachmentsObject

Returns the value of attribute has_attachments.



31
32
33
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 31

def has_attachments
  @has_attachments
end

#idObject

Message ID



34
35
36
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 34

def id
  @id
end

#keywordsObject

Active message keywords, including system flags and custom labels.



37
38
39
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 37

def keywords
  @keywords
end

#previewObject

Returns the value of attribute preview.



39
40
41
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 39

def preview
  @preview
end

#received_atObject

Returns the value of attribute received_at.



41
42
43
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 41

def received_at
  @received_at
end

#sent_atObject

Returns the value of attribute sent_at.



43
44
45
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 43

def sent_at
  @sent_at
end

#size_bytesObject

Returns the value of attribute size_bytes.



45
46
47
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 45

def size_bytes
  @size_bytes
end

#subjectObject

Returns the value of attribute subject.



47
48
49
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 47

def subject
  @subject
end

#thread_idObject

Returns the value of attribute thread_id.



49
50
51
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 49

def thread_id
  @thread_id
end

#toObject

Returns the value of attribute to.



51
52
53
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 51

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 54

def self.attribute_map
  {
    :'attachments' => :'attachments',
    :'bcc' => :'bcc',
    :'cc' => :'cc',
    :'flags' => :'flags',
    :'folder_ids' => :'folder_ids',
    :'from' => :'from',
    :'has_attachments' => :'has_attachments',
    :'id' => :'id',
    :'keywords' => :'keywords',
    :'preview' => :'preview',
    :'received_at' => :'received_at',
    :'sent_at' => :'sent_at',
    :'size_bytes' => :'size_bytes',
    :'subject' => :'subject',
    :'thread_id' => :'thread_id',
    :'to' => :'to'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 416

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
112
113
114
115
116
117
118
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 108

def self.openapi_nullable
  Set.new([
    :'from',
    :'preview',
    :'received_at',
    :'sent_at',
    :'size_bytes',
    :'subject',
    :'thread_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 86

def self.openapi_types
  {
    :'attachments' => :'Array<MailboxAttachment>',
    :'bcc' => :'Array<MailboxAddress>',
    :'cc' => :'Array<MailboxAddress>',
    :'flags' => :'MailboxMessageFlags',
    :'folder_ids' => :'Array<String>',
    :'from' => :'MailboxAddress',
    :'has_attachments' => :'Boolean',
    :'id' => :'String',
    :'keywords' => :'Array<String>',
    :'preview' => :'String',
    :'received_at' => :'String',
    :'sent_at' => :'String',
    :'size_bytes' => :'Integer',
    :'subject' => :'String',
    :'thread_id' => :'String',
    :'to' => :'Array<MailboxAddress>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 380

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attachments == o.attachments &&
      bcc == o.bcc &&
      cc == o.cc &&
      flags == o.flags &&
      folder_ids == o.folder_ids &&
      from == o.from &&
      has_attachments == o.has_attachments &&
      id == o.id &&
      keywords == o.keywords &&
      preview == o.preview &&
      received_at == o.received_at &&
      sent_at == o.sent_at &&
      size_bytes == o.size_bytes &&
      subject == o.subject &&
      thread_id == o.thread_id &&
      to == o.to
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


403
404
405
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 403

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



409
410
411
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 409

def hash
  [attachments, bcc, cc, flags, folder_ids, from, has_attachments, id, keywords, preview, received_at, sent_at, size_bytes, subject, thread_id, to].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 245

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @bcc.nil?
    invalid_properties.push('invalid value for "bcc", bcc cannot be nil.')
  end

  if @cc.nil?
    invalid_properties.push('invalid value for "cc", cc cannot be nil.')
  end

  if @flags.nil?
    invalid_properties.push('invalid value for "flags", flags cannot be nil.')
  end

  if @folder_ids.nil?
    invalid_properties.push('invalid value for "folder_ids", folder_ids cannot be nil.')
  end

  if @has_attachments.nil?
    invalid_properties.push('invalid value for "has_attachments", has_attachments cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @keywords.nil?
    invalid_properties.push('invalid value for "keywords", keywords cannot be nil.')
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 438

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/sendmux_mailbox_generated/models/mailbox_message_summary.rb', line 285

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @bcc.nil?
  return false if @cc.nil?
  return false if @flags.nil?
  return false if @folder_ids.nil?
  return false if @has_attachments.nil?
  return false if @id.nil?
  return false if @keywords.nil?
  return false if @to.nil?
  true
end