Class: Sendmux::Mailbox::Generated::MailboxRawBodyBody

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxRawBodyBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxRawBodyBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxRawBodyBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'html')
    self.html = attributes[:'html']
  else
    self.html = nil
  end

  if attributes.key?(:'is_truncated')
    self.is_truncated = attributes[:'is_truncated']
  else
    self.is_truncated = nil
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'truncated_at_chars')
    self.truncated_at_chars = attributes[:'truncated_at_chars']
  else
    self.truncated_at_chars = nil
  end
end

Instance Attribute Details

#htmlObject

Returns the value of attribute html.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 18

def html
  @html
end

#is_truncatedObject

Returns the value of attribute is_truncated.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 20

def is_truncated
  @is_truncated
end

#textObject

Returns the value of attribute text.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 22

def text
  @text
end

#truncated_at_charsObject

Returns the value of attribute truncated_at_chars.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 24

def truncated_at_chars
  @truncated_at_chars
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 27

def self.attribute_map
  {
    :'html' => :'html',
    :'is_truncated' => :'is_truncated',
    :'text' => :'text',
    :'truncated_at_chars' => :'truncated_at_chars'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 162

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
62
63
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 57

def self.openapi_nullable
  Set.new([
    :'html',
    :'text',
    :'truncated_at_chars'
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 47

def self.openapi_types
  {
    :'html' => :'String',
    :'is_truncated' => :'Boolean',
    :'text' => :'String',
    :'truncated_at_chars' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



138
139
140
141
142
143
144
145
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 138

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      html == o.html &&
      is_truncated == o.is_truncated &&
      text == o.text &&
      truncated_at_chars == o.truncated_at_chars
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


149
150
151
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 149

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



155
156
157
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 155

def hash
  [html, is_truncated, text, truncated_at_chars].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @is_truncated.nil?
    invalid_properties.push('invalid value for "is_truncated", is_truncated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 184

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



120
121
122
123
124
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_body.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @is_truncated.nil?
  true
end