Class: Sendmux::Mailbox::Generated::MailboxRawBodyResponseAllOfData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxRawBodyResponseAllOfData
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#id ⇒ Object
Message ID.
-
#part ⇒ Object
Returns the value of attribute part.
-
#states ⇒ Object
Returns the value of attribute states.
-
#thread_id ⇒ Object
Returns the value of attribute thread_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxRawBodyResponseAllOfData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxRawBodyResponseAllOfData
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxRawBodyResponseAllOfData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxRawBodyResponseAllOfData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'body') self.body = attributes[:'body'] else self.body = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'part') self.part = attributes[:'part'] else self.part = nil end if attributes.key?(:'states') self.states = attributes[:'states'] else self.states = nil end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] else self.thread_id = nil end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 18 def body @body end |
#id ⇒ Object
Message ID
21 22 23 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 21 def id @id end |
#part ⇒ Object
Returns the value of attribute part.
23 24 25 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 23 def part @part end |
#states ⇒ Object
Returns the value of attribute states.
25 26 27 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 25 def states @states end |
#thread_id ⇒ Object
Returns the value of attribute thread_id.
27 28 29 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 27 def thread_id @thread_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 52 def self.attribute_map { :'body' => :'body', :'id' => :'id', :'part' => :'part', :'states' => :'states', :'thread_id' => :'thread_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 248 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
91 92 93 94 95 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 91 def self.openapi_all_of [ :'MailboxRawBody' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 88 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 84 def self.openapi_nullable Set.new([ :'thread_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 73 def self.openapi_types { :'body' => :'MailboxRawBodyBody', :'id' => :'String', :'part' => :'String', :'states' => :'MailboxBatchGetResultStates', :'thread_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 223 def ==(o) return true if self.equal?(o) self.class == o.class && body == o.body && id == o.id && part == o.part && states == o.states && thread_id == o.thread_id end |
#eql?(o) ⇒ Boolean
235 236 237 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 235 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
241 242 243 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 241 def hash [body, id, part, states, thread_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @body.nil? invalid_properties.push('invalid value for "body", body cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @part.nil? invalid_properties.push('invalid value for "part", part cannot be nil.') end if @states.nil? invalid_properties.push('invalid value for "states", states cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 270 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_raw_body_response_all_of_data.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @body.nil? return false if @id.nil? return false if @part.nil? part_validator = EnumAttributeValidator.new('String', ["text", "html", "both", "unknown_default_open_api"]) return false unless part_validator.valid?(@part) return false if @states.nil? true end |