Class: Sendmux::Mailbox::Generated::MailboxSessionEndpoints

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxSessionEndpoints

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxSessionEndpoints` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxSessionEndpoints`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'folders')
    if (value = attributes[:'folders']).is_a?(Array)
      self.folders = value
    end
  else
    self.folders = nil
  end

  if attributes.key?(:'mailbox')
    if (value = attributes[:'mailbox']).is_a?(Array)
      self.mailbox = value
    end
  else
    self.mailbox = nil
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  else
    self.messages = nil
  end

  if attributes.key?(:'submissions')
    if (value = attributes[:'submissions']).is_a?(Array)
      self.submissions = value
    end
  else
    self.submissions = nil
  end

  if attributes.key?(:'sync')
    if (value = attributes[:'sync']).is_a?(Array)
      self.sync = value
    end
  else
    self.sync = nil
  end

  if attributes.key?(:'threads')
    if (value = attributes[:'threads']).is_a?(Array)
      self.threads = value
    end
  else
    self.threads = nil
  end

  if attributes.key?(:'usage')
    if (value = attributes[:'usage']).is_a?(Array)
      self.usage = value
    end
  else
    self.usage = nil
  end
end

Instance Attribute Details

#foldersObject

Returns the value of attribute folders.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 18

def folders
  @folders
end

#mailboxObject

Returns the value of attribute mailbox.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 20

def mailbox
  @mailbox
end

#messagesObject

Returns the value of attribute messages.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 22

def messages
  @messages
end

#submissionsObject

Returns the value of attribute submissions.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 24

def submissions
  @submissions
end

#syncObject

Returns the value of attribute sync.



26
27
28
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 26

def sync
  @sync
end

#threadsObject

Returns the value of attribute threads.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 28

def threads
  @threads
end

#usageObject

Returns the value of attribute usage.



30
31
32
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 30

def usage
  @usage
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 33

def self.attribute_map
  {
    :'folders' => :'folders',
    :'mailbox' => :'mailbox',
    :'messages' => :'messages',
    :'submissions' => :'submissions',
    :'sync' => :'sync',
    :'threads' => :'threads',
    :'usage' => :'usage'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 296

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 56

def self.openapi_types
  {
    :'folders' => :'Array<String>',
    :'mailbox' => :'Array<String>',
    :'messages' => :'Array<String>',
    :'submissions' => :'Array<String>',
    :'sync' => :'Array<String>',
    :'threads' => :'Array<String>',
    :'usage' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      folders == o.folders &&
      mailbox == o.mailbox &&
      messages == o.messages &&
      submissions == o.submissions &&
      sync == o.sync &&
      threads == o.threads &&
      usage == o.usage
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 289

def hash
  [folders, mailbox, messages, submissions, sync, threads, usage].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @folders.nil?
    invalid_properties.push('invalid value for "folders", folders cannot be nil.')
  end

  if @mailbox.nil?
    invalid_properties.push('invalid value for "mailbox", mailbox cannot be nil.')
  end

  if @messages.nil?
    invalid_properties.push('invalid value for "messages", messages cannot be nil.')
  end

  if @submissions.nil?
    invalid_properties.push('invalid value for "submissions", submissions cannot be nil.')
  end

  if @sync.nil?
    invalid_properties.push('invalid value for "sync", sync cannot be nil.')
  end

  if @threads.nil?
    invalid_properties.push('invalid value for "threads", threads cannot be nil.')
  end

  if @usage.nil?
    invalid_properties.push('invalid value for "usage", usage cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
190
191
192
193
194
195
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_endpoints.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @folders.nil?
  return false if @mailbox.nil?
  return false if @messages.nil?
  return false if @submissions.nil?
  return false if @sync.nil?
  return false if @threads.nil?
  return false if @usage.nil?
  true
end