Class: Sendmux::Mailbox::Generated::MailboxSessionLimits

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxSessionLimits

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxSessionLimits` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxSessionLimits`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attachment_upload_bytes_max')
    self.attachment_upload_bytes_max = attributes[:'attachment_upload_bytes_max']
  else
    self.attachment_upload_bytes_max = nil
  end

  if attributes.key?(:'batch_ids_max')
    self.batch_ids_max = attributes[:'batch_ids_max']
  else
    self.batch_ids_max = nil
  end

  if attributes.key?(:'body_chars_max')
    self.body_chars_max = attributes[:'body_chars_max']
  else
    self.body_chars_max = nil
  end

  if attributes.key?(:'changes_limit_max')
    self.changes_limit_max = attributes[:'changes_limit_max']
  else
    self.changes_limit_max = nil
  end

  if attributes.key?(:'inline_attachment_bytes_max')
    self.inline_attachment_bytes_max = attributes[:'inline_attachment_bytes_max']
  else
    self.inline_attachment_bytes_max = nil
  end

  if attributes.key?(:'keywords_per_update_max')
    self.keywords_per_update_max = attributes[:'keywords_per_update_max']
  else
    self.keywords_per_update_max = nil
  end

  if attributes.key?(:'list_limit_max')
    self.list_limit_max = attributes[:'list_limit_max']
  else
    self.list_limit_max = nil
  end

  if attributes.key?(:'message_body_chars_default')
    self.message_body_chars_default = attributes[:'message_body_chars_default']
  else
    self.message_body_chars_default = nil
  end

  if attributes.key?(:'outbound_raw_message_bytes_max')
    self.outbound_raw_message_bytes_max = attributes[:'outbound_raw_message_bytes_max']
  else
    self.outbound_raw_message_bytes_max = nil
  end

  if attributes.key?(:'thread_body_chars_default')
    self.thread_body_chars_default = attributes[:'thread_body_chars_default']
  else
    self.thread_body_chars_default = nil
  end
end

Instance Attribute Details

#attachment_upload_bytes_maxObject

Returns the value of attribute attachment_upload_bytes_max.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 18

def attachment_upload_bytes_max
  @attachment_upload_bytes_max
end

#batch_ids_maxObject

Returns the value of attribute batch_ids_max.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 20

def batch_ids_max
  @batch_ids_max
end

#body_chars_maxObject

Returns the value of attribute body_chars_max.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 22

def body_chars_max
  @body_chars_max
end

#changes_limit_maxObject

Returns the value of attribute changes_limit_max.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 24

def changes_limit_max
  @changes_limit_max
end

#inline_attachment_bytes_maxObject

Returns the value of attribute inline_attachment_bytes_max.



26
27
28
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 26

def inline_attachment_bytes_max
  @inline_attachment_bytes_max
end

#keywords_per_update_maxObject

Returns the value of attribute keywords_per_update_max.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 28

def keywords_per_update_max
  @keywords_per_update_max
end

#list_limit_maxObject

Returns the value of attribute list_limit_max.



30
31
32
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 30

def list_limit_max
  @list_limit_max
end

#message_body_chars_defaultObject

Returns the value of attribute message_body_chars_default.



32
33
34
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 32

def message_body_chars_default
  @message_body_chars_default
end

#outbound_raw_message_bytes_maxObject

Returns the value of attribute outbound_raw_message_bytes_max.



34
35
36
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 34

def outbound_raw_message_bytes_max
  @outbound_raw_message_bytes_max
end

#thread_body_chars_defaultObject

Returns the value of attribute thread_body_chars_default.



36
37
38
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 36

def thread_body_chars_default
  @thread_body_chars_default
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 39

def self.attribute_map
  {
    :'attachment_upload_bytes_max' => :'attachment_upload_bytes_max',
    :'batch_ids_max' => :'batch_ids_max',
    :'body_chars_max' => :'body_chars_max',
    :'changes_limit_max' => :'changes_limit_max',
    :'inline_attachment_bytes_max' => :'inline_attachment_bytes_max',
    :'keywords_per_update_max' => :'keywords_per_update_max',
    :'list_limit_max' => :'list_limit_max',
    :'message_body_chars_default' => :'message_body_chars_default',
    :'outbound_raw_message_bytes_max' => :'outbound_raw_message_bytes_max',
    :'thread_body_chars_default' => :'thread_body_chars_default'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 360

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 65

def self.openapi_types
  {
    :'attachment_upload_bytes_max' => :'Integer',
    :'batch_ids_max' => :'Integer',
    :'body_chars_max' => :'Integer',
    :'changes_limit_max' => :'Integer',
    :'inline_attachment_bytes_max' => :'Integer',
    :'keywords_per_update_max' => :'Integer',
    :'list_limit_max' => :'Integer',
    :'message_body_chars_default' => :'Integer',
    :'outbound_raw_message_bytes_max' => :'Integer',
    :'thread_body_chars_default' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 330

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attachment_upload_bytes_max == o.attachment_upload_bytes_max &&
      batch_ids_max == o.batch_ids_max &&
      body_chars_max == o.body_chars_max &&
      changes_limit_max == o.changes_limit_max &&
      inline_attachment_bytes_max == o.inline_attachment_bytes_max &&
      keywords_per_update_max == o.keywords_per_update_max &&
      list_limit_max == o.list_limit_max &&
      message_body_chars_default == o.message_body_chars_default &&
      outbound_raw_message_bytes_max == o.outbound_raw_message_bytes_max &&
      thread_body_chars_default == o.thread_body_chars_default
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 353

def hash
  [attachment_upload_bytes_max, batch_ids_max, body_chars_max, changes_limit_max, inline_attachment_bytes_max, keywords_per_update_max, list_limit_max, message_body_chars_default, outbound_raw_message_bytes_max, thread_body_chars_default].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @attachment_upload_bytes_max.nil?
    invalid_properties.push('invalid value for "attachment_upload_bytes_max", attachment_upload_bytes_max cannot be nil.')
  end

  if @batch_ids_max.nil?
    invalid_properties.push('invalid value for "batch_ids_max", batch_ids_max cannot be nil.')
  end

  if @body_chars_max.nil?
    invalid_properties.push('invalid value for "body_chars_max", body_chars_max cannot be nil.')
  end

  if @changes_limit_max.nil?
    invalid_properties.push('invalid value for "changes_limit_max", changes_limit_max cannot be nil.')
  end

  if @inline_attachment_bytes_max.nil?
    invalid_properties.push('invalid value for "inline_attachment_bytes_max", inline_attachment_bytes_max cannot be nil.')
  end

  if @keywords_per_update_max.nil?
    invalid_properties.push('invalid value for "keywords_per_update_max", keywords_per_update_max cannot be nil.')
  end

  if @list_limit_max.nil?
    invalid_properties.push('invalid value for "list_limit_max", list_limit_max cannot be nil.')
  end

  if @message_body_chars_default.nil?
    invalid_properties.push('invalid value for "message_body_chars_default", message_body_chars_default cannot be nil.')
  end

  if @outbound_raw_message_bytes_max.nil?
    invalid_properties.push('invalid value for "outbound_raw_message_bytes_max", outbound_raw_message_bytes_max cannot be nil.')
  end

  if @thread_body_chars_default.nil?
    invalid_properties.push('invalid value for "thread_body_chars_default", thread_body_chars_default cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_limits.rb', line 213

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @attachment_upload_bytes_max.nil?
  return false if @batch_ids_max.nil?
  return false if @body_chars_max.nil?
  return false if @changes_limit_max.nil?
  return false if @inline_attachment_bytes_max.nil?
  return false if @keywords_per_update_max.nil?
  return false if @list_limit_max.nil?
  return false if @message_body_chars_default.nil?
  return false if @outbound_raw_message_bytes_max.nil?
  return false if @thread_body_chars_default.nil?
  true
end