Class: Sendmux::Mailbox::Generated::MailboxThreadSummary

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxThreadSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxThreadSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxThreadSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'folder_ids')
    if (value = attributes[:'folder_ids']).is_a?(Array)
      self.folder_ids = value
    end
  else
    self.folder_ids = nil
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'last_message')
    self.last_message = attributes[:'last_message']
  else
    self.last_message = nil
  end

  if attributes.key?(:'message_count')
    self.message_count = attributes[:'message_count']
  else
    self.message_count = nil
  end

  if attributes.key?(:'participants')
    if (value = attributes[:'participants']).is_a?(Array)
      self.participants = value
    end
  else
    self.participants = nil
  end

  if attributes.key?(:'states')
    self.states = attributes[:'states']
  else
    self.states = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'unread_count')
    self.unread_count = attributes[:'unread_count']
  else
    self.unread_count = nil
  end
end

Instance Attribute Details

#folder_idsObject

Returns the value of attribute folder_ids.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 18

def folder_ids
  @folder_ids
end

#has_attachmentsObject

Returns the value of attribute has_attachments.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 20

def has_attachments
  @has_attachments
end

#idObject

Thread ID



23
24
25
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 23

def id
  @id
end

#last_messageObject

Returns the value of attribute last_message.



25
26
27
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 25

def last_message
  @last_message
end

#message_countObject

Returns the value of attribute message_count.



27
28
29
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 27

def message_count
  @message_count
end

#participantsObject

Returns the value of attribute participants.



29
30
31
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 29

def participants
  @participants
end

#statesObject

Returns the value of attribute states.



31
32
33
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 31

def states
  @states
end

#subjectObject

Returns the value of attribute subject.



33
34
35
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 33

def subject
  @subject
end

#unread_countObject

Returns the value of attribute unread_count.



35
36
37
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 35

def unread_count
  @unread_count
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 38

def self.attribute_map
  {
    :'folder_ids' => :'folder_ids',
    :'has_attachments' => :'has_attachments',
    :'id' => :'id',
    :'last_message' => :'last_message',
    :'message_count' => :'message_count',
    :'participants' => :'participants',
    :'states' => :'states',
    :'subject' => :'subject',
    :'unread_count' => :'unread_count'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 325

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
82
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 78

def self.openapi_nullable
  Set.new([
    :'subject',
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 63

def self.openapi_types
  {
    :'folder_ids' => :'Array<String>',
    :'has_attachments' => :'Boolean',
    :'id' => :'String',
    :'last_message' => :'MailboxThreadSummaryLastMessage',
    :'message_count' => :'Integer',
    :'participants' => :'Array<MailboxAddress>',
    :'states' => :'MailboxThreadSummaryStates',
    :'subject' => :'String',
    :'unread_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 296

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      folder_ids == o.folder_ids &&
      has_attachments == o.has_attachments &&
      id == o.id &&
      last_message == o.last_message &&
      message_count == o.message_count &&
      participants == o.participants &&
      states == o.states &&
      subject == o.subject &&
      unread_count == o.unread_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


312
313
314
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 312

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



318
319
320
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 318

def hash
  [folder_ids, has_attachments, id, last_message, message_count, participants, states, subject, unread_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @folder_ids.nil?
    invalid_properties.push('invalid value for "folder_ids", folder_ids cannot be nil.')
  end

  if @has_attachments.nil?
    invalid_properties.push('invalid value for "has_attachments", has_attachments cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @last_message.nil?
    invalid_properties.push('invalid value for "last_message", last_message cannot be nil.')
  end

  if @message_count.nil?
    invalid_properties.push('invalid value for "message_count", message_count cannot be nil.')
  end

  if @participants.nil?
    invalid_properties.push('invalid value for "participants", participants cannot be nil.')
  end

  if @states.nil?
    invalid_properties.push('invalid value for "states", states cannot be nil.')
  end

  if @unread_count.nil?
    invalid_properties.push('invalid value for "unread_count", unread_count cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 347

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/sendmux_mailbox_generated/models/mailbox_thread_summary.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @folder_ids.nil?
  return false if @has_attachments.nil?
  return false if @id.nil?
  return false if @last_message.nil?
  return false if @message_count.nil?
  return false if @participants.nil?
  return false if @states.nil?
  return false if @unread_count.nil?
  true
end