Class: Sendmux::Mailbox::Generated::SendMailboxMessageBody

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendMailboxMessageBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::SendMailboxMessageBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::SendMailboxMessageBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'bcc')
    if (value = attributes[:'bcc']).is_a?(Array)
      self.bcc = value
    end
  end

  if attributes.key?(:'cc')
    if (value = attributes[:'cc']).is_a?(Array)
      self.cc = value
    end
  end

  if attributes.key?(:'custom_headers')
    if (value = attributes[:'custom_headers']).is_a?(Hash)
      self.custom_headers = value
    end
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'html_body')
    self.html_body = attributes[:'html_body']
  end

  if attributes.key?(:'reply_to')
    if (value = attributes[:'reply_to']).is_a?(Array)
      self.reply_to = value
    end
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'text_body')
    self.text_body = attributes[:'text_body']
  end

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  else
    self.to = nil
  end
end

Instance Attribute Details

#attachmentsObject

Attachments to send with the message.



19
20
21
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 19

def attachments
  @attachments
end

#bccObject

BCC recipients.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 22

def bcc
  @bcc
end

#ccObject

CC recipients.



25
26
27
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 25

def cc
  @cc
end

#custom_headersObject

Custom headers to include.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 28

def custom_headers
  @custom_headers
end

#fromObject

Sender address. Defaults to mailbox identity.



31
32
33
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 31

def from
  @from
end

#html_bodyObject

HTML body.



34
35
36
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 34

def html_body
  @html_body
end

#reply_toObject

Reply-To recipients.



37
38
39
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 37

def reply_to
  @reply_to
end

#subjectObject

Subject line for the outgoing email.



40
41
42
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 40

def subject
  @subject
end

#text_bodyObject

Plain text body.



43
44
45
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 43

def text_body
  @text_body
end

#toObject

Primary recipients.



46
47
48
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 46

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 49

def self.attribute_map
  {
    :'attachments' => :'attachments',
    :'bcc' => :'bcc',
    :'cc' => :'cc',
    :'custom_headers' => :'custom_headers',
    :'from' => :'from',
    :'html_body' => :'html_body',
    :'reply_to' => :'reply_to',
    :'subject' => :'subject',
    :'text_body' => :'text_body',
    :'to' => :'to'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 255

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 75

def self.openapi_types
  {
    :'attachments' => :'Array<SendMailboxMessageBodyAttachmentsInner>',
    :'bcc' => :'Array<MailboxAddress>',
    :'cc' => :'Array<MailboxAddress>',
    :'custom_headers' => :'Hash<String, String>',
    :'from' => :'MailboxAddress',
    :'html_body' => :'String',
    :'reply_to' => :'Array<MailboxAddress>',
    :'subject' => :'String',
    :'text_body' => :'String',
    :'to' => :'Array<MailboxAddress>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 225

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attachments == o.attachments &&
      bcc == o.bcc &&
      cc == o.cc &&
      custom_headers == o.custom_headers &&
      from == o.from &&
      html_body == o.html_body &&
      reply_to == o.reply_to &&
      subject == o.subject &&
      text_body == o.text_body &&
      to == o.to
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 248

def hash
  [attachments, bcc, cc, custom_headers, from, html_body, reply_to, subject, text_body, to].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @subject.nil?
    invalid_properties.push('invalid value for "subject", subject cannot be nil.')
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @to.length < 1
    invalid_properties.push('invalid value for "to", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
197
# File 'lib/sendmux_mailbox_generated/models/send_mailbox_message_body.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @subject.nil?
  return false if @to.nil?
  return false if @to.length < 1
  true
end