Class: Sendmux::Mailbox::Generated::UpdateMailboxIdentityBody

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateMailboxIdentityBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::UpdateMailboxIdentityBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::UpdateMailboxIdentityBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'html_signature')
    self.html_signature = attributes[:'html_signature']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'text_signature')
    self.text_signature = attributes[:'text_signature']
  end
end

Instance Attribute Details

#html_signatureObject

HTML signature appended to Mailbox API sends that include html_body.



19
20
21
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 19

def html_signature
  @html_signature
end

#nameObject

Default sender name. Send null or an empty string to clear it.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 22

def name
  @name
end

#text_signatureObject

Plain text signature appended to Mailbox API sends that include text_body.



25
26
27
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 25

def text_signature
  @text_signature
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 28

def self.attribute_map
  {
    :'html_signature' => :'html_signature',
    :'name' => :'name',
    :'text_signature' => :'text_signature'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
60
61
62
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 56

def self.openapi_nullable
  Set.new([
    :'html_signature',
    :'name',
    :'text_signature'
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 47

def self.openapi_types
  {
    :'html_signature' => :'String',
    :'name' => :'String',
    :'text_signature' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      html_signature == o.html_signature &&
      name == o.name &&
      text_signature == o.text_signature
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 171

def hash
  [html_signature, name, text_signature].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 95

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@html_signature.nil? && @html_signature.to_s.length > 2047
    invalid_properties.push('invalid value for "html_signature", the character length must be smaller than or equal to 2047.')
  end

  if !@name.nil? && @name.to_s.length > 254
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 254.')
  end

  if !@text_signature.nil? && @text_signature.to_s.length > 2047
    invalid_properties.push('invalid value for "text_signature", the character length must be smaller than or equal to 2047.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



115
116
117
118
119
120
121
# File 'lib/sendmux_mailbox_generated/models/update_mailbox_identity_body.rb', line 115

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@html_signature.nil? && @html_signature.to_s.length > 2047
  return false if !@name.nil? && @name.to_s.length > 254
  return false if !@text_signature.nil? && @text_signature.to_s.length > 2047
  true
end