Class: Sendmux::Mailbox::Generated::MailboxBatchGetBody

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxBatchGetBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxBatchGetBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxBatchGetBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'body_mode')
    self.body_mode = attributes[:'body_mode']
  end

  if attributes.key?(:'ids')
    if (value = attributes[:'ids']).is_a?(Array)
      self.ids = value
    end
  else
    self.ids = nil
  end

  if attributes.key?(:'include_attachments')
    self.include_attachments = attributes[:'include_attachments']
  end

  if attributes.key?(:'include_headers')
    self.include_headers = attributes[:'include_headers']
  end

  if attributes.key?(:'include_html')
    self.include_html = attributes[:'include_html']
  end

  if attributes.key?(:'include_links')
    self.include_links = attributes[:'include_links']
  end

  if attributes.key?(:'max_body_chars')
    self.max_body_chars = attributes[:'max_body_chars']
  end

  if attributes.key?(:'part')
    self.part = attributes[:'part']
  end

  if attributes.key?(:'strip_quotes')
    self.strip_quotes = attributes[:'strip_quotes']
  end

  if attributes.key?(:'strip_signature')
    self.strip_signature = attributes[:'strip_signature']
  end
end

Instance Attribute Details

#body_modeObject

Returns the value of attribute body_mode.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 18

def body_mode
  @body_mode
end

#idsObject

Returns the value of attribute ids.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 20

def ids
  @ids
end

#include_attachmentsObject

Returns the value of attribute include_attachments.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 22

def include_attachments
  @include_attachments
end

#include_headersObject

Returns the value of attribute include_headers.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 24

def include_headers
  @include_headers
end

#include_htmlObject

Returns the value of attribute include_html.



26
27
28
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 26

def include_html
  @include_html
end

Returns the value of attribute include_links.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 28

def include_links
  @include_links
end

#max_body_charsObject

Returns the value of attribute max_body_chars.



30
31
32
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 30

def max_body_chars
  @max_body_chars
end

#partObject

Returns the value of attribute part.



32
33
34
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 32

def part
  @part
end

#strip_quotesObject

Returns the value of attribute strip_quotes.



34
35
36
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 34

def strip_quotes
  @strip_quotes
end

#strip_signatureObject

Returns the value of attribute strip_signature.



36
37
38
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 36

def strip_signature
  @strip_signature
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 61

def self.attribute_map
  {
    :'body_mode' => :'body_mode',
    :'ids' => :'ids',
    :'include_attachments' => :'include_attachments',
    :'include_headers' => :'include_headers',
    :'include_html' => :'include_html',
    :'include_links' => :'include_links',
    :'max_body_chars' => :'max_body_chars',
    :'part' => :'part',
    :'strip_quotes' => :'strip_quotes',
    :'strip_signature' => :'strip_signature'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 325

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 87

def self.openapi_types
  {
    :'body_mode' => :'String',
    :'ids' => :'Array<String>',
    :'include_attachments' => :'String',
    :'include_headers' => :'String',
    :'include_html' => :'Boolean',
    :'include_links' => :'Boolean',
    :'max_body_chars' => :'Integer',
    :'part' => :'String',
    :'strip_quotes' => :'Boolean',
    :'strip_signature' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 295

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      body_mode == o.body_mode &&
      ids == o.ids &&
      include_attachments == o.include_attachments &&
      include_headers == o.include_headers &&
      include_html == o.include_html &&
      include_links == o.include_links &&
      max_body_chars == o.max_body_chars &&
      part == o.part &&
      strip_quotes == o.strip_quotes &&
      strip_signature == o.strip_signature
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


312
313
314
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 312

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



318
319
320
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 318

def hash
  [body_mode, ids, include_attachments, include_headers, include_html, include_links, max_body_chars, part, strip_quotes, strip_signature].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ids.nil?
    invalid_properties.push('invalid value for "ids", ids cannot be nil.')
  end

  if @ids.length > 100
    invalid_properties.push('invalid value for "ids", number of items must be less than or equal to 100.')
  end

  if @ids.length < 1
    invalid_properties.push('invalid value for "ids", number of items must be greater than or equal to 1.')
  end

  if !@max_body_chars.nil? && @max_body_chars > 1000000
    invalid_properties.push('invalid value for "max_body_chars", must be smaller than or equal to 1000000.')
  end

  if !@max_body_chars.nil? && @max_body_chars < 1
    invalid_properties.push('invalid value for "max_body_chars", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 347

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/sendmux_mailbox_generated/models/mailbox_batch_get_body.rb', line 199

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  body_mode_validator = EnumAttributeValidator.new('String', ["none", "raw", "clean_json", "unknown_default_open_api"])
  return false unless body_mode_validator.valid?(@body_mode)
  return false if @ids.nil?
  return false if @ids.length > 100
  return false if @ids.length < 1
  include_attachments_validator = EnumAttributeValidator.new('String', ["none", "metadata", "unknown_default_open_api"])
  return false unless include_attachments_validator.valid?(@include_attachments)
  include_headers_validator = EnumAttributeValidator.new('String', ["none", "selected", "full", "unknown_default_open_api"])
  return false unless include_headers_validator.valid?(@include_headers)
  return false if !@max_body_chars.nil? && @max_body_chars > 1000000
  return false if !@max_body_chars.nil? && @max_body_chars < 1
  part_validator = EnumAttributeValidator.new('String', ["auto", "text", "html", "both", "unknown_default_open_api"])
  return false unless part_validator.valid?(@part)
  true
end