Class: Sendmux::Mailbox::Generated::MailboxChanges

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_mailbox_generated/models/mailbox_changes.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxChanges

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxChanges` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxChanges`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created')
    if (value = attributes[:'created']).is_a?(Array)
      self.created = value
    end
  else
    self.created = nil
  end

  if attributes.key?(:'destroyed')
    if (value = attributes[:'destroyed']).is_a?(Array)
      self.destroyed = value
    end
  else
    self.destroyed = nil
  end

  if attributes.key?(:'has_more')
    self.has_more = attributes[:'has_more']
  else
    self.has_more = nil
  end

  if attributes.key?(:'new_state')
    self.new_state = attributes[:'new_state']
  else
    self.new_state = nil
  end

  if attributes.key?(:'old_state')
    self.old_state = attributes[:'old_state']
  else
    self.old_state = nil
  end

  if attributes.key?(:'updated')
    if (value = attributes[:'updated']).is_a?(Array)
      self.updated = value
    end
  else
    self.updated = nil
  end

  if attributes.key?(:'updated_properties')
    if (value = attributes[:'updated_properties']).is_a?(Array)
      self.updated_properties = value
    end
  end
end

Instance Attribute Details

#createdObject

Returns the value of attribute created.



18
19
20
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 18

def created
  @created
end

#destroyedObject

Returns the value of attribute destroyed.



20
21
22
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 20

def destroyed
  @destroyed
end

#has_moreObject

Returns the value of attribute has_more.



22
23
24
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 22

def has_more
  @has_more
end

#new_stateObject

Returns the value of attribute new_state.



24
25
26
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 24

def new_state
  @new_state
end

#old_stateObject

Returns the value of attribute old_state.



26
27
28
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 26

def old_state
  @old_state
end

#updatedObject

Returns the value of attribute updated.



28
29
30
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 28

def updated
  @updated
end

#updated_propertiesObject

Returns the value of attribute updated_properties.



30
31
32
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 30

def updated_properties
  @updated_properties
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 33

def self.attribute_map
  {
    :'created' => :'created',
    :'destroyed' => :'destroyed',
    :'has_more' => :'has_more',
    :'new_state' => :'new_state',
    :'old_state' => :'old_state',
    :'updated' => :'updated',
    :'updated_properties' => :'updated_properties'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
73
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 69

def self.openapi_nullable
  Set.new([
    :'old_state',
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 56

def self.openapi_types
  {
    :'created' => :'Array<String>',
    :'destroyed' => :'Array<String>',
    :'has_more' => :'Boolean',
    :'new_state' => :'String',
    :'old_state' => :'String',
    :'updated' => :'Array<String>',
    :'updated_properties' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
242
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      destroyed == o.destroyed &&
      has_more == o.has_more &&
      new_state == o.new_state &&
      old_state == o.old_state &&
      updated == o.updated &&
      updated_properties == o.updated_properties
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 252

def hash
  [created, destroyed, has_more, new_state, old_state, updated, updated_properties].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @destroyed.nil?
    invalid_properties.push('invalid value for "destroyed", destroyed cannot be nil.')
  end

  if @has_more.nil?
    invalid_properties.push('invalid value for "has_more", has_more cannot be nil.')
  end

  if @new_state.nil?
    invalid_properties.push('invalid value for "new_state", new_state cannot be nil.')
  end

  if @updated.nil?
    invalid_properties.push('invalid value for "updated", updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 281

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
# File 'lib/sendmux_mailbox_generated/models/mailbox_changes.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created.nil?
  return false if @destroyed.nil?
  return false if @has_more.nil?
  return false if @new_state.nil?
  return false if @updated.nil?
  true
end