Class: Sendmux::Mailbox::Generated::MailboxFolder
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxFolder
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_folder.rb
Instance Attribute Summary collapse
-
#can_add_items ⇒ Object
Whether messages can be moved into this folder.
-
#id ⇒ Object
Folder ID.
-
#name ⇒ Object
Returns the value of attribute name.
-
#parent_id ⇒ Object
Returns the value of attribute parent_id.
-
#role ⇒ Object
System role when the folder is a built-in folder.
-
#sort_order ⇒ Object
Returns the value of attribute sort_order.
-
#total_messages ⇒ Object
Returns the value of attribute total_messages.
-
#unread_messages ⇒ Object
Returns the value of attribute unread_messages.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxFolder
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxFolder
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxFolder` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxFolder`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'can_add_items') self.can_add_items = attributes[:'can_add_items'] else self.can_add_items = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] else self.parent_id = nil end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = nil end if attributes.key?(:'sort_order') self.sort_order = attributes[:'sort_order'] else self.sort_order = nil end if attributes.key?(:'total_messages') self. = attributes[:'total_messages'] else self. = nil end if attributes.key?(:'unread_messages') self. = attributes[:'unread_messages'] else self. = nil end end |
Instance Attribute Details
#can_add_items ⇒ Object
Whether messages can be moved into this folder.
19 20 21 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 19 def can_add_items @can_add_items end |
#id ⇒ Object
Folder ID
22 23 24 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 22 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 24 def name @name end |
#parent_id ⇒ Object
Returns the value of attribute parent_id.
26 27 28 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 26 def parent_id @parent_id end |
#role ⇒ Object
System role when the folder is a built-in folder.
29 30 31 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 29 def role @role end |
#sort_order ⇒ Object
Returns the value of attribute sort_order.
31 32 33 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 31 def sort_order @sort_order end |
#total_messages ⇒ Object
Returns the value of attribute total_messages.
33 34 35 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 33 def @total_messages end |
#unread_messages ⇒ Object
Returns the value of attribute unread_messages.
35 36 37 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 35 def @unread_messages end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 38 def self.attribute_map { :'can_add_items' => :'can_add_items', :'id' => :'id', :'name' => :'name', :'parent_id' => :'parent_id', :'role' => :'role', :'sort_order' => :'sort_order', :'total_messages' => :'total_messages', :'unread_messages' => :'unread_messages' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 269 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 76 def self.openapi_nullable Set.new([ :'parent_id', :'role', :'sort_order', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 62 def self.openapi_types { :'can_add_items' => :'Boolean', :'id' => :'String', :'name' => :'String', :'parent_id' => :'String', :'role' => :'String', :'sort_order' => :'Integer', :'total_messages' => :'Integer', :'unread_messages' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && can_add_items == o.can_add_items && id == o.id && name == o.name && parent_id == o.parent_id && role == o.role && sort_order == o.sort_order && == o. && == o. end |
#eql?(o) ⇒ Boolean
256 257 258 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 256 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 262 def hash [can_add_items, id, name, parent_id, role, sort_order, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @can_add_items.nil? invalid_properties.push('invalid value for "can_add_items", can_add_items cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @total_messages.nil? invalid_properties.push('invalid value for "total_messages", total_messages cannot be nil.') end if @unread_messages.nil? invalid_properties.push('invalid value for "unread_messages", unread_messages cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 291 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_folder.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @can_add_items.nil? return false if @id.nil? return false if @name.nil? return false if @total_messages.nil? return false if @unread_messages.nil? true end |