Class: Sendmux::Mailbox::Generated::MailboxQuota
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxQuota
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_quota.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#hard_limit ⇒ Object
Returns the value of attribute hard_limit.
-
#id ⇒ Object
Quota ID.
-
#name ⇒ Object
Returns the value of attribute name.
-
#resource_type ⇒ Object
Returns the value of attribute resource_type.
-
#scope ⇒ Object
Returns the value of attribute scope.
-
#soft_limit ⇒ Object
Returns the value of attribute soft_limit.
-
#types ⇒ Object
Returns the value of attribute types.
-
#used ⇒ Object
Returns the value of attribute used.
-
#warn_limit ⇒ Object
Returns the value of attribute warn_limit.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxQuota
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxQuota
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxQuota` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxQuota`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'hard_limit') self.hard_limit = attributes[:'hard_limit'] else self.hard_limit = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] else self.resource_type = nil end if attributes.key?(:'scope') self.scope = attributes[:'scope'] else self.scope = nil end if attributes.key?(:'soft_limit') self.soft_limit = attributes[:'soft_limit'] else self.soft_limit = nil end if attributes.key?(:'types') if (value = attributes[:'types']).is_a?(Array) self.types = value end else self.types = nil end if attributes.key?(:'used') self.used = attributes[:'used'] else self.used = nil end if attributes.key?(:'warn_limit') self.warn_limit = attributes[:'warn_limit'] else self.warn_limit = nil end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 18 def description @description end |
#hard_limit ⇒ Object
Returns the value of attribute hard_limit.
20 21 22 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 20 def hard_limit @hard_limit end |
#id ⇒ Object
Quota ID
23 24 25 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 23 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
25 26 27 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 25 def name @name end |
#resource_type ⇒ Object
Returns the value of attribute resource_type.
27 28 29 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 27 def resource_type @resource_type end |
#scope ⇒ Object
Returns the value of attribute scope.
29 30 31 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 29 def scope @scope end |
#soft_limit ⇒ Object
Returns the value of attribute soft_limit.
31 32 33 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 31 def soft_limit @soft_limit end |
#types ⇒ Object
Returns the value of attribute types.
33 34 35 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 33 def types @types end |
#used ⇒ Object
Returns the value of attribute used.
35 36 37 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 35 def used @used end |
#warn_limit ⇒ Object
Returns the value of attribute warn_limit.
37 38 39 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 37 def warn_limit @warn_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 40 def self.attribute_map { :'description' => :'description', :'hard_limit' => :'hard_limit', :'id' => :'id', :'name' => :'name', :'resource_type' => :'resource_type', :'scope' => :'scope', :'soft_limit' => :'soft_limit', :'types' => :'types', :'used' => :'used', :'warn_limit' => :'warn_limit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 321 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 87 88 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 82 def self.openapi_nullable Set.new([ :'description', :'soft_limit', :'warn_limit' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 66 def self.openapi_types { :'description' => :'String', :'hard_limit' => :'Integer', :'id' => :'String', :'name' => :'String', :'resource_type' => :'String', :'scope' => :'String', :'soft_limit' => :'Integer', :'types' => :'Array<String>', :'used' => :'Integer', :'warn_limit' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && hard_limit == o.hard_limit && id == o.id && name == o.name && resource_type == o.resource_type && scope == o.scope && soft_limit == o.soft_limit && types == o.types && used == o.used && warn_limit == o.warn_limit end |
#eql?(o) ⇒ Boolean
308 309 310 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 308 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 314 def hash [description, hard_limit, id, name, resource_type, scope, soft_limit, types, used, warn_limit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @hard_limit.nil? invalid_properties.push('invalid value for "hard_limit", hard_limit cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @resource_type.nil? invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.') end if @scope.nil? invalid_properties.push('invalid value for "scope", scope cannot be nil.') end if @types.nil? invalid_properties.push('invalid value for "types", types cannot be nil.') end if @used.nil? invalid_properties.push('invalid value for "used", used cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_quota.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @hard_limit.nil? return false if @id.nil? return false if @name.nil? return false if @resource_type.nil? return false if @scope.nil? return false if @types.nil? return false if @used.nil? true end |