Class: Sendmux::Mailbox::Generated::MailboxRealtimeEvent
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxRealtimeEvent
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#is_spam ⇒ Object
Returns the value of attribute is_spam.
-
#mailbox_id ⇒ Object
Returns the value of attribute mailbox_id.
-
#message ⇒ Object
Returns the value of attribute message.
-
#message_id ⇒ Object
Returns the value of attribute message_id.
-
#message_id_kind ⇒ Object
Returns the value of attribute message_id_kind.
-
#occurred_at ⇒ Object
Returns the value of attribute occurred_at.
-
#recipients ⇒ Object
Returns the value of attribute recipients.
-
#sender ⇒ Object
Returns the value of attribute sender.
-
#team_public_id ⇒ Object
Returns the value of attribute team_public_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxRealtimeEvent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxRealtimeEvent
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxRealtimeEvent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxRealtimeEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] else self.event_type = nil end if attributes.key?(:'is_spam') self.is_spam = attributes[:'is_spam'] else self.is_spam = nil end if attributes.key?(:'mailbox_id') self.mailbox_id = attributes[:'mailbox_id'] else self.mailbox_id = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end if attributes.key?(:'message_id') self. = attributes[:'message_id'] else self. = nil end if attributes.key?(:'message_id_kind') self. = attributes[:'message_id_kind'] else self. = nil end if attributes.key?(:'occurred_at') self.occurred_at = attributes[:'occurred_at'] else self.occurred_at = nil end if attributes.key?(:'recipients') if (value = attributes[:'recipients']).is_a?(Array) self.recipients = value end else self.recipients = nil end if attributes.key?(:'sender') self.sender = attributes[:'sender'] else self.sender = nil end if attributes.key?(:'team_public_id') self.team_public_id = attributes[:'team_public_id'] else self.team_public_id = nil end end |
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 18 def event_type @event_type end |
#is_spam ⇒ Object
Returns the value of attribute is_spam.
20 21 22 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 20 def is_spam @is_spam end |
#mailbox_id ⇒ Object
Returns the value of attribute mailbox_id.
22 23 24 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 22 def mailbox_id @mailbox_id end |
#message ⇒ Object
Returns the value of attribute message.
24 25 26 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 24 def @message end |
#message_id ⇒ Object
Returns the value of attribute message_id.
26 27 28 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 26 def @message_id end |
#message_id_kind ⇒ Object
Returns the value of attribute message_id_kind.
28 29 30 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 28 def @message_id_kind end |
#occurred_at ⇒ Object
Returns the value of attribute occurred_at.
30 31 32 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 30 def occurred_at @occurred_at end |
#recipients ⇒ Object
Returns the value of attribute recipients.
32 33 34 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 32 def recipients @recipients end |
#sender ⇒ Object
Returns the value of attribute sender.
34 35 36 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 34 def sender @sender end |
#team_public_id ⇒ Object
Returns the value of attribute team_public_id.
36 37 38 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 36 def team_public_id @team_public_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 61 def self.attribute_map { :'event_type' => :'event_type', :'is_spam' => :'is_spam', :'mailbox_id' => :'mailbox_id', :'message' => :'message', :'message_id' => :'message_id', :'message_id_kind' => :'message_id_kind', :'occurred_at' => :'occurred_at', :'recipients' => :'recipients', :'sender' => :'sender', :'team_public_id' => :'team_public_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 342 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 107 108 109 110 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 103 def self.openapi_nullable Set.new([ :'is_spam', :'message_id', :'message_id_kind', :'sender', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 87 def self.openapi_types { :'event_type' => :'String', :'is_spam' => :'Boolean', :'mailbox_id' => :'String', :'message' => :'MailboxRealtimeMessage', :'message_id' => :'String', :'message_id_kind' => :'String', :'occurred_at' => :'String', :'recipients' => :'Array<String>', :'sender' => :'String', :'team_public_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 312 def ==(o) return true if self.equal?(o) self.class == o.class && event_type == o.event_type && is_spam == o.is_spam && mailbox_id == o.mailbox_id && == o. && == o. && == o. && occurred_at == o.occurred_at && recipients == o.recipients && sender == o.sender && team_public_id == o.team_public_id end |
#eql?(o) ⇒ Boolean
329 330 331 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 329 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 335 def hash [event_type, is_spam, mailbox_id, , , , occurred_at, recipients, sender, team_public_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 193 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @event_type.nil? invalid_properties.push('invalid value for "event_type", event_type cannot be nil.') end if @mailbox_id.nil? invalid_properties.push('invalid value for "mailbox_id", mailbox_id cannot be nil.') end if @message.nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end if @occurred_at.nil? invalid_properties.push('invalid value for "occurred_at", occurred_at cannot be nil.') end if @recipients.nil? invalid_properties.push('invalid value for "recipients", recipients cannot be nil.') end if @team_public_id.nil? invalid_properties.push('invalid value for "team_public_id", team_public_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_realtime_event.rb', line 225 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @event_type.nil? event_type_validator = EnumAttributeValidator.new('String', ["message.received", "message.received.spam", "sync_required", "unknown_default_open_api"]) return false unless event_type_validator.valid?(@event_type) return false if @mailbox_id.nil? return false if @message.nil? = EnumAttributeValidator.new('String', ["provider", "rfc5322", "unknown_default_open_api"]) return false unless .valid?(@message_id_kind) return false if @occurred_at.nil? return false if @recipients.nil? return false if @team_public_id.nil? true end |