Class: Sendmux::Mailbox::Generated::MailboxSessionCapabilities
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxSessionCapabilities
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Returns the value of attribute attachments.
-
#folders ⇒ Object
Returns the value of attribute folders.
-
#identities ⇒ Object
Returns the value of attribute identities.
-
#messages ⇒ Object
Returns the value of attribute messages.
-
#quotas ⇒ Object
Returns the value of attribute quotas.
-
#submissions ⇒ Object
Returns the value of attribute submissions.
-
#sync ⇒ Object
Returns the value of attribute sync.
-
#threads ⇒ Object
Returns the value of attribute threads.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxSessionCapabilities
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxSessionCapabilities
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxSessionCapabilities` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxSessionCapabilities`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'attachments') self. = attributes[:'attachments'] else self. = nil end if attributes.key?(:'folders') self.folders = attributes[:'folders'] else self.folders = nil end if attributes.key?(:'identities') self.identities = attributes[:'identities'] else self.identities = nil end if attributes.key?(:'messages') self. = attributes[:'messages'] else self. = nil end if attributes.key?(:'quotas') self.quotas = attributes[:'quotas'] else self.quotas = nil end if attributes.key?(:'submissions') self.submissions = attributes[:'submissions'] else self.submissions = nil end if attributes.key?(:'sync') self.sync = attributes[:'sync'] else self.sync = nil end if attributes.key?(:'threads') self.threads = attributes[:'threads'] else self.threads = nil end end |
Instance Attribute Details
#attachments ⇒ Object
Returns the value of attribute attachments.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 18 def @attachments end |
#folders ⇒ Object
Returns the value of attribute folders.
20 21 22 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 20 def folders @folders end |
#identities ⇒ Object
Returns the value of attribute identities.
22 23 24 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 22 def identities @identities end |
#messages ⇒ Object
Returns the value of attribute messages.
24 25 26 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 24 def @messages end |
#quotas ⇒ Object
Returns the value of attribute quotas.
26 27 28 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 26 def quotas @quotas end |
#submissions ⇒ Object
Returns the value of attribute submissions.
28 29 30 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 28 def submissions @submissions end |
#sync ⇒ Object
Returns the value of attribute sync.
30 31 32 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 30 def sync @sync end |
#threads ⇒ Object
Returns the value of attribute threads.
32 33 34 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 32 def threads @threads end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 35 def self.attribute_map { :'attachments' => :'attachments', :'folders' => :'folders', :'identities' => :'identities', :'messages' => :'messages', :'quotas' => :'quotas', :'submissions' => :'submissions', :'sync' => :'sync', :'threads' => :'threads' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 308 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 59 def self.openapi_types { :'attachments' => :'MailboxSessionCapabilitiesAttachments', :'folders' => :'MailboxSessionCapabilitiesFolders', :'identities' => :'MailboxSessionCapabilitiesIdentities', :'messages' => :'MailboxSessionCapabilitiesMessages', :'quotas' => :'MailboxSessionCapabilitiesQuotas', :'submissions' => :'MailboxSessionCapabilitiesSubmissions', :'sync' => :'MailboxSessionCapabilitiesSync', :'threads' => :'MailboxSessionCapabilitiesThreads' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 280 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && folders == o.folders && identities == o.identities && == o. && quotas == o.quotas && submissions == o.submissions && sync == o.sync && threads == o.threads end |
#eql?(o) ⇒ Boolean
295 296 297 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 295 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 301 def hash [, folders, identities, , quotas, submissions, sync, threads].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @attachments.nil? invalid_properties.push('invalid value for "attachments", attachments cannot be nil.') end if @folders.nil? invalid_properties.push('invalid value for "folders", folders cannot be nil.') end if @identities.nil? invalid_properties.push('invalid value for "identities", identities cannot be nil.') end if @messages.nil? invalid_properties.push('invalid value for "messages", messages cannot be nil.') end if @quotas.nil? invalid_properties.push('invalid value for "quotas", quotas cannot be nil.') end if @submissions.nil? invalid_properties.push('invalid value for "submissions", submissions cannot be nil.') end if @sync.nil? invalid_properties.push('invalid value for "sync", sync cannot be nil.') end if @threads.nil? invalid_properties.push('invalid value for "threads", threads cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 330 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_session_capabilities.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @attachments.nil? return false if @folders.nil? return false if @identities.nil? return false if @messages.nil? return false if @quotas.nil? return false if @submissions.nil? return false if @sync.nil? return false if @threads.nil? true end |