Class: Sendmux::Mailbox::Generated::MailboxSubmission
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxSubmission
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_submission.rb
Instance Attribute Summary collapse
-
#delivery_status ⇒ Object
Returns the value of attribute delivery_status.
-
#dsn_blob_ids ⇒ Object
Returns the value of attribute dsn_blob_ids.
-
#email_id ⇒ Object
Returns the value of attribute email_id.
-
#envelope ⇒ Object
Returns the value of attribute envelope.
-
#id ⇒ Object
Submission ID.
-
#identity_id ⇒ Object
Returns the value of attribute identity_id.
-
#mdn_blob_ids ⇒ Object
Returns the value of attribute mdn_blob_ids.
-
#send_at ⇒ Object
Returns the value of attribute send_at.
-
#thread_id ⇒ Object
Returns the value of attribute thread_id.
-
#undo_status ⇒ Object
Returns the value of attribute undo_status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxSubmission
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxSubmission
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxSubmission` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxSubmission`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'delivery_status') if (value = attributes[:'delivery_status']).is_a?(Array) self.delivery_status = value end else self.delivery_status = nil end if attributes.key?(:'dsn_blob_ids') if (value = attributes[:'dsn_blob_ids']).is_a?(Array) self.dsn_blob_ids = value end else self.dsn_blob_ids = nil end if attributes.key?(:'email_id') self.email_id = attributes[:'email_id'] else self.email_id = nil end if attributes.key?(:'envelope') self.envelope = attributes[:'envelope'] else self.envelope = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'identity_id') self.identity_id = attributes[:'identity_id'] else self.identity_id = nil end if attributes.key?(:'mdn_blob_ids') if (value = attributes[:'mdn_blob_ids']).is_a?(Array) self.mdn_blob_ids = value end else self.mdn_blob_ids = nil end if attributes.key?(:'send_at') self.send_at = attributes[:'send_at'] else self.send_at = nil end if attributes.key?(:'thread_id') self.thread_id = attributes[:'thread_id'] else self.thread_id = nil end if attributes.key?(:'undo_status') self.undo_status = attributes[:'undo_status'] else self.undo_status = nil end end |
Instance Attribute Details
#delivery_status ⇒ Object
Returns the value of attribute delivery_status.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 18 def delivery_status @delivery_status end |
#dsn_blob_ids ⇒ Object
Returns the value of attribute dsn_blob_ids.
20 21 22 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 20 def dsn_blob_ids @dsn_blob_ids end |
#email_id ⇒ Object
Returns the value of attribute email_id.
22 23 24 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 22 def email_id @email_id end |
#envelope ⇒ Object
Returns the value of attribute envelope.
24 25 26 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 24 def envelope @envelope end |
#id ⇒ Object
Submission ID
27 28 29 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 27 def id @id end |
#identity_id ⇒ Object
Returns the value of attribute identity_id.
29 30 31 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 29 def identity_id @identity_id end |
#mdn_blob_ids ⇒ Object
Returns the value of attribute mdn_blob_ids.
31 32 33 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 31 def mdn_blob_ids @mdn_blob_ids end |
#send_at ⇒ Object
Returns the value of attribute send_at.
33 34 35 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 33 def send_at @send_at end |
#thread_id ⇒ Object
Returns the value of attribute thread_id.
35 36 37 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 35 def thread_id @thread_id end |
#undo_status ⇒ Object
Returns the value of attribute undo_status.
37 38 39 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 37 def undo_status @undo_status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 40 def self.attribute_map { :'delivery_status' => :'delivery_status', :'dsn_blob_ids' => :'dsn_blob_ids', :'email_id' => :'email_id', :'envelope' => :'envelope', :'id' => :'id', :'identity_id' => :'identity_id', :'mdn_blob_ids' => :'mdn_blob_ids', :'send_at' => :'send_at', :'thread_id' => :'thread_id', :'undo_status' => :'undo_status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 283 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 82 def self.openapi_nullable Set.new([ :'email_id', :'envelope', :'identity_id', :'send_at', :'thread_id', :'undo_status' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 66 def self.openapi_types { :'delivery_status' => :'Array<MailboxSubmissionDeliveryStatus>', :'dsn_blob_ids' => :'Array<String>', :'email_id' => :'String', :'envelope' => :'MailboxSubmissionEnvelope', :'id' => :'String', :'identity_id' => :'String', :'mdn_blob_ids' => :'Array<String>', :'send_at' => :'String', :'thread_id' => :'String', :'undo_status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 253 def ==(o) return true if self.equal?(o) self.class == o.class && delivery_status == o.delivery_status && dsn_blob_ids == o.dsn_blob_ids && email_id == o.email_id && envelope == o.envelope && id == o.id && identity_id == o.identity_id && mdn_blob_ids == o.mdn_blob_ids && send_at == o.send_at && thread_id == o.thread_id && undo_status == o.undo_status end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 276 def hash [delivery_status, dsn_blob_ids, email_id, envelope, id, identity_id, mdn_blob_ids, send_at, thread_id, undo_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 178 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @delivery_status.nil? invalid_properties.push('invalid value for "delivery_status", delivery_status cannot be nil.') end if @dsn_blob_ids.nil? invalid_properties.push('invalid value for "dsn_blob_ids", dsn_blob_ids cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @mdn_blob_ids.nil? invalid_properties.push('invalid value for "mdn_blob_ids", mdn_blob_ids cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 209 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_submission.rb', line 202 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @delivery_status.nil? return false if @dsn_blob_ids.nil? return false if @id.nil? return false if @mdn_blob_ids.nil? true end |