Class: Sendmux::Mailbox::Generated::MailboxUsageResource
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Mailbox::Generated::MailboxUsageResource
- Defined in:
- lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#hard_limit ⇒ Object
Returns the value of attribute hard_limit.
-
#limit_status ⇒ Object
Returns the value of attribute limit_status.
-
#name ⇒ Object
Returns the value of attribute name.
-
#percent_used ⇒ Object
Returns the value of attribute percent_used.
-
#quota_id ⇒ Object
Returns the value of attribute quota_id.
-
#resource_type ⇒ Object
Returns the value of attribute resource_type.
-
#scope ⇒ Object
Returns the value of attribute scope.
-
#soft_limit ⇒ Object
Returns the value of attribute soft_limit.
-
#types ⇒ Object
Returns the value of attribute types.
-
#used ⇒ Object
Returns the value of attribute used.
-
#warn_limit ⇒ Object
Returns the value of attribute warn_limit.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxUsageResource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxUsageResource
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Mailbox::Generated::MailboxUsageResource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Mailbox::Generated::MailboxUsageResource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'hard_limit') self.hard_limit = attributes[:'hard_limit'] else self.hard_limit = nil end if attributes.key?(:'limit_status') self.limit_status = attributes[:'limit_status'] else self.limit_status = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'percent_used') self.percent_used = attributes[:'percent_used'] else self.percent_used = nil end if attributes.key?(:'quota_id') self.quota_id = attributes[:'quota_id'] else self.quota_id = nil end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] else self.resource_type = nil end if attributes.key?(:'scope') self.scope = attributes[:'scope'] else self.scope = nil end if attributes.key?(:'soft_limit') self.soft_limit = attributes[:'soft_limit'] else self.soft_limit = nil end if attributes.key?(:'types') if (value = attributes[:'types']).is_a?(Array) self.types = value end else self.types = nil end if attributes.key?(:'used') self.used = attributes[:'used'] else self.used = nil end if attributes.key?(:'warn_limit') self.warn_limit = attributes[:'warn_limit'] else self.warn_limit = nil end end |
Instance Attribute Details
#hard_limit ⇒ Object
Returns the value of attribute hard_limit.
18 19 20 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 18 def hard_limit @hard_limit end |
#limit_status ⇒ Object
Returns the value of attribute limit_status.
20 21 22 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 20 def limit_status @limit_status end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 22 def name @name end |
#percent_used ⇒ Object
Returns the value of attribute percent_used.
24 25 26 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 24 def percent_used @percent_used end |
#quota_id ⇒ Object
Returns the value of attribute quota_id.
26 27 28 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 26 def quota_id @quota_id end |
#resource_type ⇒ Object
Returns the value of attribute resource_type.
28 29 30 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 28 def resource_type @resource_type end |
#scope ⇒ Object
Returns the value of attribute scope.
30 31 32 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 30 def scope @scope end |
#soft_limit ⇒ Object
Returns the value of attribute soft_limit.
32 33 34 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 32 def soft_limit @soft_limit end |
#types ⇒ Object
Returns the value of attribute types.
34 35 36 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 34 def types @types end |
#used ⇒ Object
Returns the value of attribute used.
36 37 38 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 36 def used @used end |
#warn_limit ⇒ Object
Returns the value of attribute warn_limit.
38 39 40 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 38 def warn_limit @warn_limit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 63 def self.attribute_map { :'hard_limit' => :'hard_limit', :'limit_status' => :'limit_status', :'name' => :'name', :'percent_used' => :'percent_used', :'quota_id' => :'quota_id', :'resource_type' => :'resource_type', :'scope' => :'scope', :'soft_limit' => :'soft_limit', :'types' => :'types', :'used' => :'used', :'warn_limit' => :'warn_limit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 370 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 111 112 113 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 107 def self.openapi_nullable Set.new([ :'percent_used', :'soft_limit', :'warn_limit' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 90 def self.openapi_types { :'hard_limit' => :'Integer', :'limit_status' => :'String', :'name' => :'String', :'percent_used' => :'Float', :'quota_id' => :'String', :'resource_type' => :'String', :'scope' => :'String', :'soft_limit' => :'Integer', :'types' => :'Array<String>', :'used' => :'Integer', :'warn_limit' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 339 def ==(o) return true if self.equal?(o) self.class == o.class && hard_limit == o.hard_limit && limit_status == o.limit_status && name == o.name && percent_used == o.percent_used && quota_id == o.quota_id && resource_type == o.resource_type && scope == o.scope && soft_limit == o.soft_limit && types == o.types && used == o.used && warn_limit == o.warn_limit end |
#eql?(o) ⇒ Boolean
357 358 359 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 357 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
363 364 365 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 363 def hash [hard_limit, limit_status, name, percent_used, quota_id, resource_type, scope, soft_limit, types, used, warn_limit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @hard_limit.nil? invalid_properties.push('invalid value for "hard_limit", hard_limit cannot be nil.') end if @limit_status.nil? invalid_properties.push('invalid value for "limit_status", limit_status cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @quota_id.nil? invalid_properties.push('invalid value for "quota_id", quota_id cannot be nil.') end if @resource_type.nil? invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.') end if @scope.nil? invalid_properties.push('invalid value for "scope", scope cannot be nil.') end if @types.nil? invalid_properties.push('invalid value for "types", types cannot be nil.') end if @used.nil? invalid_properties.push('invalid value for "used", used cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 392 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/sendmux_mailbox_generated/models/mailbox_usage_resource.rb', line 242 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @hard_limit.nil? return false if @limit_status.nil? limit_status_validator = EnumAttributeValidator.new('String', ["ok", "warning", "soft_limit", "hard_limit", "unknown", "unknown_default_open_api"]) return false unless limit_status_validator.valid?(@limit_status) return false if @name.nil? return false if @quota_id.nil? return false if @resource_type.nil? return false if @scope.nil? return false if @types.nil? return false if @used.nil? true end |